@@ -86,8 +86,9 @@ use PPI::Element    ();
 use PPI::Token      ();
 use PPI::Exception  ();
 use PPI::Exception::ParserRejection ();
+use PPI::Document ();
 
-our $VERSION = '1.280'; # TRIAL
+our $VERSION = '1.282'; # TRIAL
 
 # The x operator cannot follow most Perl operators, implying that
 # anything beginning with x following an operator is a word.
@@ -872,8 +873,7 @@ sub _current_token_has_signatures_active {
 	}
 
 	my ($closest_parented_token) = grep $_->parent, @tokens;
-	die "no parented element found" unless    #
-	  $closest_parented_token ||= $t->_document;
+	$closest_parented_token ||= $t->_document || $t->_document(PPI::Document->new);
 	return $closest_parented_token->presumed_features->{signatures}, @tokens;
 }
 
